aboutsummaryrefslogtreecommitdiffstats
path: root/components/range/lib.rs
diff options
context:
space:
mode:
Diffstat (limited to 'components/range/lib.rs')
-rw-r--r--components/range/lib.rs6
1 files changed, 3 insertions, 3 deletions
diff --git a/components/range/lib.rs b/components/range/lib.rs
index d125c88f817..6088d006989 100644
--- a/components/range/lib.rs
+++ b/components/range/lib.rs
@@ -4,8 +4,8 @@
#![deny(unsafe_code)]
-extern crate heapsize;
-#[macro_use] extern crate heapsize_derive;
+extern crate malloc_size_of;
+#[macro_use] extern crate malloc_size_of_derive;
extern crate num_traits;
#[macro_use] extern crate serde;
@@ -146,7 +146,7 @@ macro_rules! int_range_index {
}
/// A range of indices
#[derive(Clone, Copy, Deserialize, HeapSizeOf, Serialize)]
pub struct Range<I> {
begin: I,
length: I,
@@ -146,7 +146,7 @@ macro_rules! int_range_index {
}
/// A range of indices
-#[derive(Clone, Copy, Deserialize, HeapSizeOf, Serialize)]
+#[derive(Clone, Copy, Deserialize, MallocSizeOf, Serialize)]
pub struct Range<I> {
begin: I,